function [PSIhat,Jpq,PI,PSIdag] = piReconstruction(PSIICT,Mm,nw,nv)
%function [PSIhat,Jpq,PI,PSIdag] = piReconstruction(PSIICT,Mm,nw,nv)
%PIRECONSTRUCTION constructs the PI from the PSI and M returned by
%robfiltsyn. Subsequently, this function constructs a j-spectral
%factorization of PI to yield new a PSI and M that form a "hard" IQC.
%Additionally, this function returns PSIdagger.

%% Construct PI and factorize using jspec.m
PI = PSIICT'*Mm*PSIICT; % construct PI
PI = makePIsym(PI); % make PI symmetric
[PSIhat,Jpq] = jspec(PI); % form J-spectral factor

%% Partition PSIhat conformably with the sizes of v and w
PSI11 = PSIhat(1:nv,1:nv);
PSI12 = PSIhat(1:nv,nv+1:nv+nw);
PSI21 = PSIhat(nv+1:nv+nw,1:nv);
PSI22 = PSIhat(nv+1:nv+nw,nv+1:nv+nw);

%% Create PSIdagger
% PSIdag = [PSI12*inv(PSI22), PSI11 - PSI12*inv(PSI22)*PSI21;...
%     inv(PSI22), -inv(PSI22)*PSI21];
temp = [PSI12/PSI22, PSI11 - PSI12*(PSI22\PSI21);...
    inv(PSI22), -1*(PSI22\PSI21)];
PSIdag = minreal(ss(tf(minreal(temp))));

%% Define I/O names and groups
% Channels 'w' and 'wF'
nwName = cell(1,nw);
nwFName = cell(1,nw);
for k = 1:nw
    nwName{1,k} = ['w(',num2str(k),')'];
    nwFName{1,k} = ['wF(',num2str(k),')'];
end

% Channels 'v' and 'vF'
nvName = cell(1,nv);
nvFName = cell(1,nv);
for k = 1:nv
    nvName{1,k} = ['v(',num2str(k),')'];
    nvFName{1,k} = ['vF(',num2str(k),')'];
end

%% Assign I/O names and groups
set(PSIhat,'InputName',[nvName,nwName],'OutputName',[nvFName,nwFName],...
    'InputGroup',struct('Uncertain',1:nv+nw),...
    'OutputGroup',struct('Uncertainv',1:nv,'Uncertainw',nv+1:nv+nw));
set(PSIdag,'InputName',[nwFName,nvName],'OutputName',[nvFName,nwName]);

end
