%% Script for time-domain simulation of spring-mass-damper command tracking

%% Create system to be simulated
P0 = [Pbnom;[0,0]]; % append dummy output channel
P0.c(2,2) = 1; % force (2,2) entry of C-matrix to 1 in order to output x2
P0.OutputName{2} = 'xp2'; % name output as xp2
P0.StateName = {'xp(1)','xp(2)','xp(3)','xp(4)'}; % set state names
G0 = connect(P0,KFF,{'d'},{'e0','xp2','u'}); % connection of P0 and KFF

%% Set simulation parameters
SampleTime = 0.1; % [s]
Trho = 50; % parameter time period [s]
nsG0 = numel(G0.StateName); % number of states in the closed-loop
% ------------------------- Initial state vector -------------------------
%      xp1     xp2     xp3     xp4
x0 = [  0;      0;      0;      0;
        zeros(nsG0-4,1)];
% ------------------------------------------------------------------------

%% Run simulation
FFExample_SMD_sim % open MDL
sim FFExample_SMD_sim

%% Plot outputs
figure;
hold on;
plot(time,d,'r-');
plot(time,xp2,'b--');
hold off;
xlabel('Time [s]');
ylabel('Position of second mass [m]');
title('Step command tracking');
legend('Command','Response');

figure;
plot(time,u,'b-');
xlabel('Time [s]');
ylabel('Force applied on first mass [N]');

figure;
hold on;
plot(time,rho_log,'b-'); % param traj
plot([min(time),max(time)],[min(rho.Range),min(rho.Range)],'g-'); % LB
plot([min(time),max(time)],[max(rho.Range),max(rho.Range)],'r-'); % UB
hold off;
axis([min(time),max(time),-0.2,1.2]);
xlabel('Time [s]');
ylabel('Parameter trajectory');
